@@ -57,13 +57,20 @@ CRM_EQUIPES_ENDPOINT = {
     }
 }
 
-MIDIAS = {
+PLAY_MIDIAS_ENDPOINT = {
     "midias": {
         "resource": "/midias/",
         "methods": ["GET"]
     }
 }
 
+CRM_MIDIAS_ENDPOINT = {
+    "midias": {
+        "resource": "/backend/midias/",
+        "methods": ["GET"]
+    }
+}
+
 INTERFACE = {
     "interface": {
         "resource": "/backend/perfil/{codigo}/interface/",
